Module config

Module config 

Structs

ContentHash
ValueLocation
The on-disk file name and byte offsets that provide the config value. Useful if applications want to edit config values in-place.
ValueSource
A config value with associated metadata like where it comes from.

Traits

Config
Readable config. This can be used as a trait object.
ConfigExt
Extra APIs (incompatible with trait objects) around reading config.