Module config
configmodel
0.1.0
Module config
Module Items
Structs
Traits
In crate configmodel
configmodel
Module
config
Structs

Content
Hash
Value
Location
The on-disk file name and byte offsets that provide the config value. Useful if applications want to edit config values in-place.
Value
A config value with associated metadata like where it comes from.
Traits

Config
Readable config. This can be used as a trait object.
Config
Ext
Extra APIs (incompatible with trait objects) around reading config.